package org.eclipse.jdt.internal.compiler.impl;

package .tmp;

import org.eclipse.jdt.internal.compiler.impl.Constant;

public class LongConstant extends Constant {
  private static final org.eclipse.jdt.internal.compiler.impl.LongConstant ZERO = new org.eclipse.jdt.internal.compiler.impl.LongConstant(0L);
  
  private static final org.eclipse.jdt.internal.compiler.impl.LongConstant MIN_VALUE = new org.eclipse.jdt.internal.compiler.impl.LongConstant(Long.MIN_VALUE);
  
  private long value;
  
  public static Constant fromValue(long value) {
    if (value == 0L)
      return ZERO; 
    if (value == Long.MIN_VALUE)
      return MIN_VALUE; 
    return new org.eclipse.jdt.internal.compiler.impl.LongConstant(value);
  }
  
  private LongConstant(long value) {
    this.value = value;
  }
  
  public byte byteValue() {
    return (byte)(int)this.value;
  }
  
  public char charValue() {
    return (char)(int)this.value;
  }
  
  public double doubleValue() {
    return this.value;
  }
  
  public float floatValue() {
    return (float)this.value;
  }
  
  public int intValue() {
    return (int)this.value;
  }
  
  public long longValue() {
    return this.value;
  }
  
  public short shortValue() {
    return (short)(int)this.value;
  }
  
  public String stringValue() {
    return String.valueOf(this.value);
  }
  
  public String toString() {
    return "(long)" + this.value;
  }
  
  public int typeID() {
    return 7;
  }
  
  public int hashCode() {
    return (int)(this.value ^ this.value >>> 32L);
  }
  
  public boolean equals(Object obj) {
    if (this == obj)
      return true; 
    if (obj == null)
      return false; 
    if (getClass() != obj.getClass())
      return false; 
    org.eclipse.jdt.internal.compiler.impl.LongConstant other = (org.eclipse.jdt.internal.compiler.impl.LongConstant)obj;
    return (this.value == other.value);
  }
}
